@@ -81,7 +81,7 @@ class Model(ApiObject):
         if self.status != 'running':
             raise RuntimeError('status must be running')
 
-        return api_post(f'api/models/{self.model_id}/prediction/update', data = json.dumps(dict(prediction_id = prediction_id, actual = actual)))
+        return api_put(f'api/models/{self.model_id}/predictions/{prediction_id}', data = json.dumps(actual))
 
     def _predict(self, data, prediction_method):
         if self.status != 'running':
@@ -90,7 +90,7 @@ class Model(ApiObject):
         if prediction_method not in self.prediction_methods:
             raise NotImplementedError(f'{prediction_method} not implemented in model')
 
-        return api_post(f'api/models/{self.model_id}/prediction', data = json.dumps(dict(data = data, prediction_method = prediction_method)))
+        return api_post(f'api/models/{self.model_id}/predictions', data = json.dumps(dict(data = data, prediction_method = prediction_method)))
 
     def _predict_batch(self, data, prediction_method, upload_func):
         if self.status != 'running':
