@@ -195,8 +195,8 @@ class BinaryTransformer(BaseEstimator, TransformerMixin):
             transforms.append(binary)
         return pd.concat(transforms, axis=1).mask(pd.isnull(X)).astype('O')
 
-class UnknownToNanTransformer(BaseEstimator, TransformerMixin):
-    """Sets unknown categories to nan."""
+class NominalTransformer(BaseEstimator, TransformerMixin):
+    """Converts categoricals to nominals and replaces missing and unknowns with nan."""
     def fit(self, X, y = None):
         """
         Fits transformer to X.
@@ -215,7 +215,7 @@ class UnknownToNanTransformer(BaseEstimator, TransformerMixin):
 
     def transform(self, X):
         """
-        Replaces missing and unknowns with nan.
+        Ordinal encodes and replaces missing and unknowns with nan.
 
         Args:
             X: DataFrame.
@@ -223,11 +223,19 @@ class UnknownToNanTransformer(BaseEstimator, TransformerMixin):
         Returns:
             DataFrame.
         """
-        idx_unknowns = []
-        for col, s in X.items():
-            idx_unknowns.append(~s.isin(self.categories[col]))
-
-        return X.mask(pd.concat(idx_unknowns, axis=1))
+        index = X.index
+        columns = X.columns
+        X = X.to_numpy()
+        
+        output = np.empty(X.shape)
+        output[:] = np.nan
+        
+        for i, col in enumerate(columns):
+            for j, cat in enumerate(self.categories[col]):
+                idx = X[:,i] == cat
+                output[idx,i] = j
+        
+        return pd.DataFrame(output, index = index, columns = columns)
 
 class ColumnTransformer(BaseEstimator, TransformerMixin):
     """ColumnTransformer specifically for DataFrame.
